#ifndef SDLEXCEPTION_H
#define SDLEXCEPTION_H

#include "Exception.h"

//----------------------------------------------------------------------------
class SDLException : public Exception
{
  public:
    SDLException(const char *call);
    ~SDLException();

    std::string toString() const;

  protected:
    const char *m_call;
    const char *m_sdlError;
};

#endif //SDLEXCEPTION_H
